api.users.v1.test_helpers.group package — Argus-Toolbelt 1.0 documentation

# api.users.v1.test_helpers.group package

## Submodules

## api.users.v1.test_helpers.group.find_groups module

`api.users.v1.test_helpers.group.find_groups.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/search, respond with HTTP 403

`api.users.v1.test_helpers.group.find_groups.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/search, respond with HTTP 404

`api.users.v1.test_helpers.group.find_groups.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/search, respond with HTTP 200

`api.users.v1.test_helpers.group.find_groups.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/search, respond with HTTP 401

## api.users.v1.test_helpers.group.get_gropu_by_id module

`api.users.v1.test_helpers.group.get_gropu_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 403

`api.users.v1.test_helpers.group.get_gropu_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 404

`api.users.v1.test_helpers.group.get_gropu_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 200

`api.users.v1.test_helpers.group.get_gropu_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 401

## api.users.v1.test_helpers.group.get_group_by_name module

`api.users.v1.test_helpers.group.get_group_by_name.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 403

`api.users.v1.test_helpers.group.get_group_by_name.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 404

`api.users.v1.test_helpers.group.get_group_by_name.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 200

`api.users.v1.test_helpers.group.get_group_by_name.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group/w+, respond with HTTP 401

## api.users.v1.test_helpers.group.list_groups module

`api.users.v1.test_helpers.group.list_groups.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group, respond with HTTP 403

`api.users.v1.test_helpers.group.list_groups.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group, respond with HTTP 404

`api.users.v1.test_helpers.group.list_groups.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group, respond with HTTP 200

`api.users.v1.test_helpers.group.list_groups.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/group, respond with HTTP 401

## Module contents